aboutsummaryrefslogtreecommitdiff
path: root/lib/pleroma/web/controller_helper.ex
diff options
context:
space:
mode:
Diffstat (limited to 'lib/pleroma/web/controller_helper.ex')
-rw-r--r--lib/pleroma/web/controller_helper.ex6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/pleroma/web/controller_helper.ex b/lib/pleroma/web/controller_helper.ex
index ae9b265b1..ff94c6be0 100644
--- a/lib/pleroma/web/controller_helper.ex
+++ b/lib/pleroma/web/controller_helper.ex
@@ -104,8 +104,8 @@ defmodule Pleroma.Web.ControllerHelper do
def put_if_exist(map, key, value), do: Map.put(map, key, value)
- def embed_relationships?(params) do
- # To do: change to `truthy_param?(params["embed_relationships"])` once PleromaFE supports it
- not explicitly_falsy_param?(params["embed_relationships"])
+ def with_relationships?(params) do
+ # To do: change to `truthy_param?(params["with_relationships"])` once PleromaFE supports it
+ not explicitly_falsy_param?(params["with_relationships"])
end
end